microSD Card control function for DISCO-F469NI based on BD_SD_DISCO_F746NG library by Roy Krikke

Dependencies:   BSP_DISCO_F469NI_modified BD_SD_DISCO_F469NI

Fork of DISCO-F769NI_BD_SD_Card_Control by Kenji Arai

Please refer following my Notebook page.
/users/kenjiArai/notebook/sd-card-control-new/

Revision:
9:b819be925e97
Parent:
8:3c5373ba612a
Child:
10:b5665028f662
--- a/check_revision.cpp	Sat Dec 07 03:26:31 2019 +0000
+++ b/check_revision.cpp	Fri Dec 27 02:59:09 2019 +0000
@@ -5,22 +5,17 @@
  *  http://www.page.sannet.ne.jp/kenjia/index.html
  *  https://os.mbed.com/users/kenjiArai/
  *      Created:    July      17th, 2019
- *      Revised:    December   6th, 2019
+ *      Revised:    December  27th, 2019
  */
 
 #include "mbed.h"
 
 //    RUN ONLY ON mbed-os5.14.2
 //      https://github.com/ARMmbed/mbed-os/releases/tag/mbed-os-5.14.2
 #if (MBED_MAJOR_VERSION == 5) &&\
-    (MBED_MINOR_VERSION == 14) &&\
-    (MBED_PATCH_VERSION == 2)
-    #if defined(TARGET_STM32F469NI)
-        // correct mbed-os version
-    #else
-        #error "DISCO-F469NI"
-    #endif
+    (MBED_MINOR_VERSION == 15) &&\
+    (MBED_PATCH_VERSION == 0)
 #else
-    //#warning "Please use Mbed-os5.14.2"
-    #error "Please use Mbed-os5.14.2"
-#endif
\ No newline at end of file
+    //#warning "Please use Mbed-os5.15.0"
+    #error "Please use Mbed-os5.15.0"
+#endif
@@ -5,22 +5,17 @@
 #include "mbed.h"
 
-//    RUN ONLY ON mbed-os5.14.2
-//      https://github.com/ARMmbed/mbed-os/releases/tag/mbed-os-5.14.2
+//    RUN ONLY ON mbed-os5.15.0
+//      https://github.com/ARMmbed/mbed-os/releases/tag/mbed-os-5.15.0
 #if (MBED_MAJOR_VERSION == 5) &&\